@@ -22,7 +22,7 @@ user.option <- function(i,uniquecsid,cntryname,G.names) {
 # time series plotter
 timeplot <- function(x,geoname,dvlabel,cntryname,
                      time.insamp.obs,time.insamp.predict,time.xlab,
-                     time.ylab,age.incl) {
+                     time.ylab,age.incl,args.matplot) {
 
  # Set up labels 
  if(is.null(time.xlab)) {time.xlab <- "Time"}
@@ -53,26 +53,50 @@ timeplot <- function(x,geoname,dvlabel,cntryname,
  if(!time.insamp.obs) {
    ylim <- c(min(na.omit(geoname$yhat)),max(na.omit(geoname$yhat)))
  }
+
+ # Compile arguments to matplot
+ args.matplot$x <- as.integer(years)
+ args.matplot$y <- geoname$yhat
+ args.matplot$xlab <- time.xlab
+ args.matplot$ylab <- time.ylab
+ if(is.null(args.matplot$xlim)){args.matplot$xlim <-
+                                  c(as.integer(years)[1],
+                                    as.integer(years)[nrow(geoname$yhat)]+
+                                    0.075*(max(as.integer(years))-
+                                           min(as.integer(years))))}
+ if(is.null(args.matplot$main)){args.matplot$main <-
+                                  paste(if(!is.null(dvlabel)){dvlabel},
+                                        if(!is.null(dvlabel) & !is.null(cntryname)){", "},
+                                        if(!is.null(cntryname)){cntryname},sep="")}
+ if(is.null(args.matplot$ylim)){args.matplot$ylim <- ylim}
+ if(is.null(args.matplot$type)){args.matplot$type <- "l"}
+ if(is.null(args.matplot$lty)){args.matplot$lty <- 1}
+ if(is.null(args.matplot$col)){args.matplot$col <-
+                                 rainbow(ncol(geoname$yhat))}
+ suppressWarnings(do.call("matplot",args=args.matplot))
+ 
+                               
  
   # plot the predicted values
-  suppressWarnings(
-  matplot(x=as.integer(years),y=geoname$yhat,
-          type="l",lty=1,col=rainbow(ncol(geoname$yhat)),
-          xlab=time.xlab,ylab=time.ylab,
-          xlim=c(as.integer(years)[1],
-            as.integer(years)[nrow(geoname$yhat)]+
-            0.075*(max(as.integer(years))-
-                  min(as.integer(years)))),
-          ylim=ylim,
-          main=paste(if(!is.null(dvlabel)){dvlabel},
-            if(!is.null(dvlabel) & !is.null(cntryname)){", "},
-            if(!is.null(cntryname)){cntryname},sep=""))
- )
+#                                        #suppressWarnings(
+# 
+# matplot(x=as.integer(years),y=geoname$yhat,
+#         type="l",lty=1,col=rainbow(ncol(geoname$yhat)),
+#         xlab=time.xlab,ylab=time.ylab,
+#         xlim=c(as.integer(years)[1],
+#           as.integer(years)[nrow(geoname$yhat)]+
+#           0.075*(max(as.integer(years))-
+#                  min(as.integer(years)))),
+#          ylim=ylim,
+#         main=paste(if(!is.null(dvlabel)){dvlabel},
+#           if(!is.null(dvlabel) & !is.null(cntryname)){", "},
+#           if(!is.null(cntryname)){cntryname},sep=""))
+#                                        #)
   
   # only plot the observed values if time.insamp.obs==T
   if(time.insamp.obs) {
   matlines(x=as.integer(rownames(geoname$y)),y=geoname$y,
-           type="l",lty=2,col=rainbow(ncol(geoname$y)))
+           type="l",lty=2,col=args.matplot$col)
 }
 
   # plotting labels on predicted lines
@@ -93,14 +117,14 @@ timeplot <- function(x,geoname,dvlabel,cntryname,
  text(x=xp,y=yp,
       labels=labels[order(unlist(geoname$yhat[nrow(geoname$yhat),]))],
       pos=4,cex=0.85,
-      col=rainbow(ncol(geoname$yhat))[order(unlist(geoname$yhat[nrow(geoname$yhat),]))])
+      col=args.matplot$col[order(unlist(geoname$yhat[nrow(geoname$yhat),]))])
 }
 
 
 ####################################################
 # age profile plotter
 ageplot <- function(x,geoname,dvlabel,cntryname,
-                    age.insamp.predict,age.xlab,age.ylab) {
+                    age.insamp.predict,age.xlab,age.ylab,args.matplot){
 
  # Set up labels 
  if(is.null(age.xlab)) {age.xlab <- "Age"}
@@ -111,17 +135,20 @@ ageplot <- function(x,geoname,dvlabel,cntryname,
  
  # If not age.insamp.predict, remove the in sample observations
  # from the 'yhat' dataframe and adjust colors and axes
- col <- rainbow(nrow(geoname$yhat))
+ if(is.null(args.matplot$col)){col <- rainbow(nrow(geoname$yhat))}
+ else{col <- args.matplot$col}
  ylim <- c(min(geoname$yhat),max(geoname$yhat)+
            abs(0.05*max(geoname$yhat)))
  yp <- rep(max(geoname$yhat)+abs(0.025*max(geoname$yhat)),
            nrow(geoname$yhat))
+ 
+ # If want observed values, change some inputs
  if(!age.insamp.predict) {
    sample.frame <- x$aux$sample.frame;
    geoname$yhat[c(1:grep(sample.frame[2],
-                         years)),] <- NA;
-   col <- col[grep(sample.frame[3],years):
-              nrow(geoname$yhat)];
+                         years)),] <- NA
+   args.matplot$col <- col[grep(sample.frame[3],years):
+                           nrow(geoname$yhat)]
    ylim <- c(min(min(na.omit(geoname$yhat)),
                  min(na.omit(geoname$y))),
              max(max(na.omit(geoname$yhat)),
@@ -134,27 +161,41 @@ ageplot <- function(x,geoname,dvlabel,cntryname,
              nrow(geoname$yhat))
  }
 
- # plot predicted values
- suppressWarnings(
-                  matplot(x=as.integer(ages),
-                          y=t(geoname$yhat),type="l",lty=1,
-                          col=col,xlab=age.xlab,ylab=age.ylab,
-                          ylim=ylim,
-                          main=paste(if(!is.null(dvlabel)){dvlabel},
-                            if(!is.null(dvlabel) & !is.null(cntryname)){", "},
-                            if(!is.null(cntryname)){cntryname},sep=""))
-                  )
+
+  # Compile arguments to matplot
+ args.matplot$x <- as.integer(ages)
+ args.matplot$y <- t(geoname$yhat)
+ args.matplot$xlab <- age.xlab
+ args.matplot$ylab <- age.ylab
+ if(is.null(args.matplot$main)){args.matplot$main <-
+                                  paste(if(!is.null(dvlabel)){dvlabel},
+                                        if(!is.null(dvlabel) & !is.null(cntryname)){", "},
+                                        if(!is.null(cntryname)){cntryname},sep="")}
+ if(is.null(args.matplot$ylim)){args.matplot$ylim <- ylim}
+ if(is.null(args.matplot$type)){args.matplot$type <- "l"}
+ if(is.null(args.matplot$lty)){args.matplot$lty <- 1}
+ args.matplot$col <- col
+ suppressWarnings(do.call("matplot",args=args.matplot))
+
+ 
+# # plot predicted values
+# suppressWarnings(
+#                  matplot(x=as.integer(ages),
+#                          y=t(geoname$yhat),type="l",lty=1,
+#                          col=col,xlab=age.xlab,ylab=age.ylab,
+#                          ylim=ylim,
+#                          main=paste(if(!is.null(dvlabel)){dvlabel},
+#                            if(!is.null(dvlabel) & !is.null(cntryname)){", "},
+#                            if(!is.null(cntryname)){cntryname},sep=""))
+#                  )
 
   # plot legend
  range.ages <- range(as.numeric(ages))
  spread.ages <- range.ages[2]-range.ages[1]
  range.xp <- c(range.ages[1]+spread.ages*0.08,range.ages[1]+spread.ages*0.33)
  xp <- seq(range.xp[1],range.xp[2],length=nrow(geoname$yhat))
- #xp <- seq(as.integer(ages)[2],
- #          as.integer(ages)[round(ncol(geoname$yhat)/3)],
- #          length=nrow(geoname$yhat))
  yp <- yp
- points(x=xp,y=yp,col=rainbow(nrow(geoname$yhat)))
+ points(x=xp,y=yp,col=col)
  text(x=xp[1],y=yp[1],labels=years[1],pos=2)
  text(x=xp[length(xp)],y=yp[length(yp)],
       labels=years[nrow(geoname$yhat)],pos=4)
@@ -163,10 +204,12 @@ ageplot <- function(x,geoname,dvlabel,cntryname,
  if(!age.insamp.predict) {
    suppressWarnings(
                     matlines(x=as.integer(colnames(geoname$y)),
-                             y=t(geoname$y),type="l",lty=1,
-                             col=rainbow(nrow(geoname$yhat))[1:nrow(geoname$y)])
+                             y=t(geoname$y),
+                             type=args.matplot$type,
+                             lty=args.matplot$lty,
+                             col=col[1:nrow(geoname$y)])
                     )
- }
+                  }
  
  
 }
@@ -178,13 +221,14 @@ threedimplot <- function(x,geoname,dvlabel,cntryname,
                          threedim.insamp.predict,
                          screen=list(z=-40, x=-60, y=0),
                          threedim.xlab,threedim.ylab,
-                         threedim.zlab) {
+                         threedim.zlab,
+                         args.wireframe) {
 
   # Set up labels 
   if(is.null(threedim.xlab)) {threedim.xlab <- "Year"}
   if(is.null(threedim.ylab)) {threedim.ylab <- "Age"}
   if(is.null(threedim.zlab)) {threedim.zlab <- "Forecasts"}
-  ages <- ages
+  ages <- colnames(geoname$yhat)
   years <- rownames(geoname$yhat)
 
   if(threedim.insamp.predict) {
@@ -212,19 +256,34 @@ threedimplot <- function(x,geoname,dvlabel,cntryname,
   }
   
   # create lattice object
-  out <- wireframe(z ~ x * y, data=data, xlab=threedim.xlab,
-                   ylab=threedim.ylab,zlab=threedim.zlab,
-                   shade=TRUE,scales=list(arrows=F),
-                   screen = screen,
-                   main=paste(if(!is.null(dvlabel)){dvlabel},
+  args.wireframe$x <- z ~ x * y
+  args.wireframe$data <- data
+  args.wireframe$xlab <- threedim.xlab
+  args.wireframe$ylab <- threedim.ylab
+  args.wireframe$zlab <- threedim.zlab
+  args.wireframe$screen <- screen
+  args.wireframe$main <- paste(if(!is.null(dvlabel)){dvlabel},
                      if(!is.null(dvlabel) & !is.null(cntryname)){", "},
-                     if(!is.null(cntryname)){cntryname},sep=""))
+                     if(!is.null(cntryname)){cntryname},sep="")
+  if(is.null(args.wireframe$shade)){args.wireframe$shade <- TRUE}
+  if(is.null(args.wireframe$scales)){args.wireframe$scales <-
+                                       list(arrows=F)}
+  out <- do.call("wireframe",args=args.wireframe)
+  
+#  out <- wireframe(z ~ x * y, data=data, xlab=threedim.xlab,
+#                   ylab=threedim.ylab,zlab=threedim.zlab,
+#                   shade=TRUE,scales=list(arrows=F),
+#                   screen = screen,
+#                   main=paste(if(!is.null(dvlabel)){dvlabel},
+#                     if(!is.null(dvlabel) & !is.null(cntryname)){", "},
+#                     if(!is.null(cntryname)){cntryname},sep=""))
   return(out)
 }
 
 ####################################################
 # main function
 plot.yourcast <- function(x,dpath=getwd(),dvlabel=NULL,family="agetime",
+                          args.matplot=list(),args.wireframe=list(),
                           time.insamp.obs=TRUE,time.insamp.predict=TRUE,
                           age.insamp.predict=TRUE,
                           threedim.insamp.predict=TRUE,
@@ -313,7 +372,7 @@ plot.yourcast <- function(x,dpath=getwd(),dvlabel=NULL,family="agetime",
       if(print=="pdf"){pdf(file=file)}
       par(...)
       ageplot(x,get(geonames[i]),dvlabel,cntryname,
-              age.insamp.predict,age.xlab,age.ylab)
+              age.insamp.predict,age.xlab,age.ylab,args.matplot)
       if(print=="pdf"){dev.off()}
       if(print=="device"){if(i != length(geonames)) {
         user.option(i,uniquecsid,cntryname,G.names)}}
@@ -334,7 +393,7 @@ plot.yourcast <- function(x,dpath=getwd(),dvlabel=NULL,family="agetime",
                                   G.names[,1]),2]}
       if(print=="pdf") {pdf(file=file)}
       timeplot(x,get(geonames[i]),dvlabel,cntryname,time.insamp.obs,
-               time.insamp.predict,time.xlab,time.ylab,age.incl)
+               time.insamp.predict,time.xlab,time.ylab,age.incl,args.matplot)
       if(print=="pdf"){dev.off()}
       if(print=="device"){if(i != length(geonames)) {
         user.option(i,uniquecsid,cntryname,G.names)}}
@@ -357,9 +416,9 @@ plot.yourcast <- function(x,dpath=getwd(),dvlabel=NULL,family="agetime",
       if(print=="pdf"){pdf(file=file,height=7,width=14)}
       par(mfrow=c(1,2),...)
       timeplot(x,get(geonames[i]),dvlabel,cntryname,time.insamp.obs,
-               time.insamp.predict,time.xlab,time.ylab,age.incl)
+               time.insamp.predict,time.xlab,time.ylab,age.incl,args.matplot)
       ageplot(x,get(geonames[i]),dvlabel,cntryname,
-              age.insamp.predict,age.xlab,age.ylab)
+              age.insamp.predict,age.xlab,age.ylab,args.matplot)
       if(print=="pdf"){dev.off()}
     if(print=="device"){if(i != length(geonames)) {
       user.option(i,uniquecsid,cntryname,G.names)}}
@@ -383,7 +442,8 @@ plot.yourcast <- function(x,dpath=getwd(),dvlabel=NULL,family="agetime",
                                cntryname,threedim.insamp.predict,
                                screen=screen,
                                threedim.xlab,threedim.ylab,
-                               threedim.zlab)
+                               threedim.zlab,
+                               args.wireframe)
       if(print=="pdf"){pdf(file=file)}
       par(...)
       print(out.plot)
